@@ -2,7 +2,7 @@ use swc_atoms::{js_word, JsWord};
 use swc_common::{collections::AHashMap, comments::Comments};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{id, Id};
-use swc_ecma_visit::{Fold, FoldWith};
+use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
 
 #[cfg(test)]
 mod tests;
@@ -11,14 +11,14 @@ mod tests;
 /// React methods, so that terser and other minifiers can safely remove them
 /// during dead code elimination.
 /// See https://reactjs.org/docs/react-api.html
-pub fn pure_annotations<C>(comments: Option<C>) -> impl Fold
+pub fn pure_annotations<C>(comments: Option<C>) -> impl Fold + VisitMut
 where
     C: Comments,
 {
-    PureAnnotations {
+    as_folder(PureAnnotations {
         imports: Default::default(),
         comments,
-    }
+    })
 }
 
 struct PureAnnotations<C>
@@ -29,16 +29,18 @@ where
     comments: Option<C>,
 }
 
-impl<C> Fold for PureAnnotations<C>
+impl<C> VisitMut for PureAnnotations<C>
 where
     C: Comments,
 {
-    fn fold_module(&mut self, module: Module) -> Module {
+    noop_visit_mut_type!();
+
+    fn visit_mut_module(&mut self, module: &mut Module) {
         // Pass 1: collect imports
         for item in &module.body {
             match item {
                 ModuleItem::ModuleDecl(ModuleDecl::Import(import)) => {
-                    let src_str = import.src.value.to_string();
+                    let src_str = &*import.src.value;
                     if src_str != "react" && src_str != "react-dom" {
                         continue;
                     }
@@ -67,11 +69,15 @@ where
             }
         }
 
+        if self.imports.is_empty() {
+            return;
+        }
+
         // Pass 2: add pure annotations.
-        module.fold_children_with(self)
+        module.visit_mut_children_with(self);
     }
 
-    fn fold_call_expr(&mut self, call: CallExpr) -> CallExpr {
+    fn visit_mut_call_expr(&mut self, call: &mut CallExpr) {
         let is_react_call = match &call.callee {
             ExprOrSuper::Expr(expr) => match &**expr {
                 Expr::Ident(ident) => {
@@ -85,8 +91,7 @@ where
                     ExprOrSuper::Expr(expr) => match &**expr {
                         Expr::Ident(ident) => {
                             if let Some((src, specifier)) = self.imports.get(&id(&ident)) {
-                                let specifier_str = specifier.to_string();
-                                if specifier_str == "default" || specifier_str == "*" {
+                                if &**specifier == "default" || &**specifier == "*" {
                                     match &*member.prop {
                                         Expr::Ident(ident) => is_pure(src, &ident.sym),
                                         _ => false,
@@ -113,18 +118,18 @@ where
             }
         }
 
-        call.fold_children_with(self)
+        call.visit_mut_children_with(self);
     }
 }
 
 fn is_pure(src: &JsWord, specifier: &JsWord) -> bool {
-    match src.to_string().as_str() {
-        "react" => match specifier.to_string().as_str() {
+    match &**src {
+        "react" => match &**specifier {
             "cloneElement" | "createContext" | "createElement" | "createFactory" | "createRef"
             | "forwardRef" | "isValidElement" | "memo" | "lazy" => true,
             _ => false,
         },
-        "react-dom" => match specifier.to_string().as_str() {
+        "react-dom" => match &**specifier {
             "createPortal" => true,
             _ => false,
         },
